@@ -22,6 +22,7 @@ region_map = {
     'EU (London)': 'eu-west-2',
     'EU (Paris)': 'eu-west-3',
     'EU (Stockholm)': 'eu-north-1',
+    'EU (Milan)': 'eu-south-1',
     'Middle East (Bahrain)': 'me-south-1',
     'South America (Sao Paulo)': 'sa-east-1',
     'US East (N. Virginia)': 'us-east-1',
@@ -39,10 +40,10 @@ class CloudProvider(object):
                'tenancy': 'Shared'
                }
 
-    def get_prices(self, **filters):
+    def get_prices(self, fail_on_missing_regions=False, **filters):
         if not filters:
             filters = self.filters
-        instances = aws_helpers.get_ec2_prices(**filters)
+        instances = aws_helpers.get_ec2_prices(fail_on_missing_regions=fail_on_missing_regions, **filters)
         # add a provider column
         instances['provider'] = self.provider
 
